# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'fitswidget.ui'
#
# Created by: PyQt5 UI code generator 5.15.7
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FitsWidget(object):
    def setupUi(self, FitsWidget):
        FitsWidget.setObjectName("FitsWidget")
        FitsWidget.resize(896, 553)
        self.verticalLayout = QtWidgets.QVBoxLayout(FitsWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.widget_2 = QtWidgets.QWidget(FitsWidget)
        self.widget_2.setObjectName("widget_2")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.widget_2)
        self.horizontalLayout_6.setContentsMargins(-1, 1, -1, 1)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem)
        self.widgetTools = QtWidgets.QWidget(self.widget_2)
        self.widgetTools.setObjectName("widgetTools")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.widgetTools)
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_4.setSpacing(0)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.horizontalLayout_6.addWidget(self.widgetTools)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem1)
        self.verticalLayout.addWidget(self.widget_2)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.widgetCanvas = QtWidgets.QWidget(FitsWidget)
        self.widgetCanvas.setObjectName("widgetCanvas")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.widgetCanvas)
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_3.setSpacing(0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.horizontalLayout_2.addWidget(self.widgetCanvas)
        self.labelColorbar = QtWidgets.QLabel(FitsWidget)
        self.labelColorbar.setMinimumSize(QtCore.QSize(30, 0))
        self.labelColorbar.setMaximumSize(QtCore.QSize(30, 16777215))
        self.labelColorbar.setText("")
        self.labelColorbar.setScaledContents(True)
        self.labelColorbar.setObjectName("labelColorbar")
        self.horizontalLayout_2.addWidget(self.labelColorbar)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.frame = QtWidgets.QFrame(FitsWidget)
        self.frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.frame)
        self.horizontalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.labelCuts = QtWidgets.QLabel(self.frame)
        self.labelCuts.setEnabled(False)
        self.labelCuts.setObjectName("labelCuts")
        self.horizontalLayout_3.addWidget(self.labelCuts)
        self.comboCuts = QtWidgets.QComboBox(self.frame)
        self.comboCuts.setEnabled(False)
        self.comboCuts.setObjectName("comboCuts")
        self.horizontalLayout_3.addWidget(self.comboCuts)
        self.spinLoCut = QtWidgets.QDoubleSpinBox(self.frame)
        self.spinLoCut.setEnabled(False)
        self.spinLoCut.setButtonSymbols(QtWidgets.QAbstractSpinBox.UpDownArrows)
        self.spinLoCut.setMinimum(-99999.0)
        self.spinLoCut.setMaximum(99999.0)
        self.spinLoCut.setObjectName("spinLoCut")
        self.horizontalLayout_3.addWidget(self.spinLoCut)
        self.spinHiCut = QtWidgets.QDoubleSpinBox(self.frame)
        self.spinHiCut.setEnabled(False)
        self.spinHiCut.setMinimum(-99999.0)
        self.spinHiCut.setMaximum(99999.0)
        self.spinHiCut.setObjectName("spinHiCut")
        self.horizontalLayout_3.addWidget(self.spinHiCut)
        spacerItem2 = QtWidgets.QSpacerItem(5, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem2)
        self.labelStretch = QtWidgets.QLabel(self.frame)
        self.labelStretch.setEnabled(False)
        self.labelStretch.setObjectName("labelStretch")
        self.horizontalLayout_3.addWidget(self.labelStretch)
        self.comboStretch = QtWidgets.QComboBox(self.frame)
        self.comboStretch.setEnabled(False)
        self.comboStretch.setObjectName("comboStretch")
        self.horizontalLayout_3.addWidget(self.comboStretch)
        spacerItem3 = QtWidgets.QSpacerItem(5, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem3)
        self.labelColormap = QtWidgets.QLabel(self.frame)
        self.labelColormap.setEnabled(False)
        self.labelColormap.setObjectName("labelColormap")
        self.horizontalLayout_3.addWidget(self.labelColormap)
        self.comboColormap = QtWidgets.QComboBox(self.frame)
        self.comboColormap.setEnabled(False)
        self.comboColormap.setObjectName("comboColormap")
        self.horizontalLayout_3.addWidget(self.comboColormap)
        self.checkColormapReverse = QtWidgets.QCheckBox(self.frame)
        self.checkColormapReverse.setEnabled(False)
        self.checkColormapReverse.setObjectName("checkColormapReverse")
        self.horizontalLayout_3.addWidget(self.checkColormapReverse)
        spacerItem4 = QtWidgets.QSpacerItem(5, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem4)
        self.checkTrimSec = QtWidgets.QCheckBox(self.frame)
        self.checkTrimSec.setEnabled(False)
        self.checkTrimSec.setChecked(True)
        self.checkTrimSec.setObjectName("checkTrimSec")
        self.horizontalLayout_3.addWidget(self.checkTrimSec)
        self.verticalLayout.addWidget(self.frame)
        self.verticalLayout.setStretch(1, 1)

        self.retranslateUi(FitsWidget)
        QtCore.QMetaObject.connectSlotsByName(FitsWidget)

    def retranslateUi(self, FitsWidget):
        _translate = QtCore.QCoreApplication.translate
        FitsWidget.setWindowTitle(_translate("FitsWidget", "Form"))
        self.labelCuts.setText(_translate("FitsWidget", "Cuts:"))
        self.labelStretch.setText(_translate("FitsWidget", "Stretch:"))
        self.labelColormap.setText(_translate("FitsWidget", "Colormap:"))
        self.checkColormapReverse.setText(_translate("FitsWidget", "reversed"))
        self.checkTrimSec.setText(_translate("FitsWidget", "trimsec"))
